package sk.upjs.ics.hangman;
import java.util.Arrays;
import java.util.List;
import java.util.Random;

import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

public class HangmanTest {

	@Test
	public void testIdealRun() {
		List<String> dictionary = Arrays.asList("troll");

		HangmanGame game = new HangmanGame(new Random(1), dictionary);
		game.guess('t');
		game.guess('r');
		game.guess('o');
		game.guess('l');
		game.guess('l');
		Assert.assertTrue(game.isWon());
	}
	
	@Test
	public void testDetailedRun() {
		List<String> dictionary = Arrays.asList("troll");

		HangmanGame game = new HangmanGame(new Random(1), dictionary);

		char[] attemptedCharacters = { 't', 'r', 'o', 'l' };
		String[] expectedGuessCharacters = { "t____", "tr___", "tro__", "troll" };

		for (int i = 0; i < attemptedCharacters.length; i++) {
			char c = attemptedCharacters[i];
			if(game.guess(c)) {
				Assert.assertEquals(expectedGuessCharacters[i], game.getGuessedCharacters().toString());
			} else {
				Assert.fail("Letter " + c + " should be guessed correctly, but it is not.");
			}
		}
		Assert.assertTrue(game.isWon());
	}	
	
	@Test
	public void testCompletelyFailedGuessing() {
		List<String> dictionary = Arrays.asList("troll");

		HangmanGame game = new HangmanGame(new Random(1), dictionary);

		for (int i = 0; i < 6; i++) {
			if(game.guess('w')) {
				Assert.fail("Letter 'w' is incorrectly guessed");
			}		
		}
		Assert.assertEquals(0, game.getAttemptsLeft());
	}		
	
 	@Test(expected=IllegalStateException.class)
	public void testTrollFailTenTimes() {
		List<String> dictionary = Arrays.asList("troll");

		HangmanGame game = new HangmanGame(new Random(1), dictionary);

		for(char c : "qwetzuipas".toCharArray()) {
			game.guess(c);
		}
		Assert.assertEquals(0, game.getAttemptsLeft());
	}			
}